==> eea.cynadmin-1.9.zip: eea.cynadmin-1.9/eea/cynadmin/skins/eea_cyn/getjsondata.py <==
###############################################################################
##cyn.in is an open source Collaborative Knowledge Management Appliance that 
##enables teams to seamlessly work together on files, documents and content in 
##a secure central environment.
##
##cyn.in v2 an open source appliance is distributed under the GPL v3 license 
##along with commercial support options.
##
##cyn.in is a Cynapse Invention.
##
##Copyright (C) 2008 Cynapse India Pvt. Ltd.
##
##This program is free software: you can redistribute it and/or modify it under
##the terms of the GNU General Public License as published by the Free Software 
##Foundation, either version 3 of the License, or any later version and observe 
##the Additional Terms applicable to this program and must display appropriate 
##legal notices. In accordance with Section 7(b) of the GNU General Public 
##License version 3, these Appropriate Legal Notices must retain the display of 
##the "Powered by cyn.in" AND "A Cynapse Invention" logos. You should have 
##received a copy of the detailed Additional Terms License with this program.
##
##This program is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of 
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
##Public License for more details.
##
##You should have received a copy of the GNU General Public License along with 
##this program.  If not, see <http://www.gnu.org/licenses/>.
##
##You can contact Cynapse at support@cynapse.com with any problems with cyn.in. 
##For any queries regarding the licensing, please send your mails to 
## legal@cynapse.com
##
##You can also contact Cynapse at:
##802, Building No. 1,
##Dheeraj Sagar, Malad(W)
##Mumbai-400064, India
###############################################################################
## Script (Python) "getjsondata"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=REQUEST=None,type=None,records=10
##title=wraps the portal_catalog with a rules qualified query
##
from ubify.cyninv2theme.portlets.statistics import getjsondata
from eea.cynadmin.portlets.statistics import eeagetjsondata

if context.REQUEST.get('type',None) is not None:
    type = context.REQUEST.get('type')
if context.REQUEST.get('records',None) is not None:
    records = context.REQUEST.get('records')

eeastatisticstypes = ['discussionstats_bar',
                      'discussionstats_pie']
if type in eeastatisticstypes:
    data = eeagetjsondata(context,int(records),type)
else:
    data = getjsondata(context,int(records),type)
return data

==> eea.cynadmin-1.14.zip: eea.cynadmin-1.14/eea/cynadmin/skins/eea_cyn/getjsondata.py <==
###############################################################################
##cyn.in is an open source Collaborative Knowledge Management Appliance that 
##enables teams to seamlessly work together on files, documents and content in 
##a secure central environment.
##
##cyn.in v2 an open source appliance is distributed under the GPL v3 license 
##along with commercial support options.
##
##cyn.in is a Cynapse Invention.
##
##Copyright (C) 2008 Cynapse India Pvt. Ltd.
##
##This program is free software: you can redistribute it and/or modify it under
##the terms of the GNU General Public License as published by the Free Software 
##Foundation, either version 3 of the License, or any later version and observe 
##the Additional Terms applicable to this program and must display appropriate 
##legal notices. In accordance with Section 7(b) of the GNU General Public 
##License version 3, these Appropriate Legal Notices must retain the display of 
##the "Powered by cyn.in" AND "A Cynapse Invention" logos. You should have 
##received a copy of the detailed Additional Terms License with this program.
##
##This program is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of 
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
##Public License for more details.
##
##You should have received a copy of the GNU General Public License along with 
##this program.  If not, see <http://www.gnu.org/licenses/>.
##
##You can contact Cynapse at support@cynapse.com with any problems with cyn.in. 
##For any queries regarding the licensing, please send your mails to 
## legal@cynapse.com
##
##You can also contact Cynapse at:
##802, Building No. 1,
##Dheeraj Sagar, Malad(W)
##Mumbai-400064, India
###############################################################################
## Script (Python) "getjsondata"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=REQUEST=None,type=None,records=10
##title=wraps the portal_catalog with a rules qualified query
##
from ubify.cyninv2theme.portlets.statistics import getjsondata
from eea.cynadmin.portlets.statistics import eeagetjsondata

if context.REQUEST.get('type',None) is not None:
    type = context.REQUEST.get('type')
if context.REQUEST.get('records',None) is not None:
    records = context.REQUEST.get('records')

eeastatisticstypes = ['discussionstats_bar',
                      'discussionstats_pie',
                      'purposestats_bar',
                      'purposestats_pie']
if type in eeastatisticstypes:
    data = eeagetjsondata(context,int(records),type)
else:
    data = getjsondata(context,int(records),type)
return data
